Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(383)

Unified Diff: chrome/browser/gtk/options/cookies_view.h

Issue 523139: Adds local storage nodes to cookie tree model and cookies view. (Closed) Base URL: http://src.chromium.org/svn/trunk/src/
Patch Set: '' Created 10 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/gtk/options/advanced_contents_gtk.cc ('k') | chrome/browser/gtk/options/cookies_view.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/gtk/options/cookies_view.h
===================================================================
--- chrome/browser/gtk/options/cookies_view.h (revision 36995)
+++ chrome/browser/gtk/options/cookies_view.h (working copy)
@@ -12,6 +12,7 @@
#include "base/basictypes.h"
#include "base/scoped_ptr.h"
#include "base/task.h"
+#include "chrome/browser/browsing_data_local_storage_helper.h"
#include "chrome/common/gtk_tree.h"
#include "net/base/cookie_monster.h"
#include "testing/gtest/include/gtest/gtest_prod.h"
@@ -31,14 +32,18 @@
virtual ~CookiesView();
// Create (if necessary) and show the cookie manager window.
- static void Show(Profile* profile);
+ static void Show(
+ Profile* profile,
+ BrowsingDataLocalStorageHelper* browsing_data_local_storage_helper);
// gtk_tree::TreeAdapter::Delegate implementation.
virtual void OnAnyModelUpdateStart();
virtual void OnAnyModelUpdate();
private:
- explicit CookiesView(Profile* profile);
+ CookiesView(
+ Profile* profile,
+ BrowsingDataLocalStorageHelper* browsing_data_local_storage_helper);
// Initialize the dialog contents and layout.
void Init();
@@ -46,8 +51,9 @@
// Initialize the widget styles and display the dialog.
void InitStylesAndShow();
- // Helper for initializing cookie details table.
- void InitCookieDetailRow(int row, int label_id, GtkWidget** display_label);
+ // Helper for initializing cookie / local storage details table.
+ void InitDetailRow(int row, int label_id,
+ GtkWidget* details_table, GtkWidget** display_label);
// Set the initial selection and tree expanded state.
void SetInitialTreeState();
@@ -58,10 +64,18 @@
// Set sensitivity of cookie details.
void SetCookieDetailsSensitivity(gboolean enabled);
+ // Set sensitivity of local storage details.
+ void SetLocalStorageDetailsSensitivity(gboolean enabled);
+
// Show the details of the currently selected cookie.
void PopulateCookieDetails(const std::string& domain,
const net::CookieMonster::CanonicalCookie& cookie);
+ // Show the details of the currently selected local storage.
+ void PopulateLocalStorageDetails(
+ const BrowsingDataLocalStorageHelper::LocalStorageInfo&
+ local_storage_info);
+
// Reset the cookie details display.
void ClearCookieDetails();
@@ -90,6 +104,9 @@
// Filter the list against the text in |filter_entry_|.
void UpdateFilterResults();
+ // Sets which of the detailed info table is visible.
+ void UpdateVisibleDetailedInfo(GtkWidget* table);
+
// Callbacks for user actions filtering the list.
static void OnFilterEntryActivated(GtkEntry* entry, CookiesView* window);
static void OnFilterEntryChanged(GtkEditable* editable, CookiesView* window);
@@ -120,9 +137,19 @@
GtkWidget* cookie_created_entry_;
GtkWidget* cookie_expires_entry_;
+ // The local storage details widgets.
+ GtkWidget* local_storage_details_table_;
+ GtkWidget* local_storage_origin_entry_;
+ GtkWidget* local_storage_size_entry_;
+ GtkWidget* local_storage_last_modified_entry_;
+
// The profile.
Profile* profile_;
+ // Local Storage Helper.
+ scoped_refptr<BrowsingDataLocalStorageHelper>
+ browsing_data_local_storage_helper_;
+
// A factory to construct Runnable Methods so that we can be called back to
// re-evaluate the model after the search query string changes.
ScopedRunnableMethodFactory<CookiesView> filter_update_factory_;
« no previous file with comments | « chrome/browser/gtk/options/advanced_contents_gtk.cc ('k') | chrome/browser/gtk/options/cookies_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698